/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import java.text.ParseException;

/**
 * I am the type of compression used to compress the data of a CBF image.
 */
public enum CbfCompression {
/* @formatter:off */
  NONE(       "x-CBF_NONE"),
  BYTE_OFFSET("x-CBF_BYTE_OFFSET");
/* @formatter:on */

  private String contentTypeConversions;

  CbfCompression(String contentTypeConversions) {
    this.contentTypeConversions = contentTypeConversions;
  }

  public boolean compatibleWith(CbfElementType type) {
    if (equals(NONE)) return true;
    return !CbfElementType.SIGNED_32_BIT_REAL_IEEE.equals(type)
      && !CbfElementType.SIGNED_64_BIT_REAL_IEEE.equals(type);
  }

  public String toContentTypeConversions() {
    return contentTypeConversions;
  }

  public static CbfCompression parse(String contentTypeConversions) throws ParseException {
    String trimmed = contentTypeConversions.trim();
    for (CbfCompression each : values())
      if (each.toContentTypeConversions().equals(trimmed)) return each;
    throw new ParseException("Unsupported conversions: " + trimmed, 0);
  }
}
