/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.Locale;

import javax.imageio.ImageTypeSpecifier;
import javax.imageio.ImageWriter;
import javax.imageio.spi.ImageWriterSpi;

/**
 * I am a writer SPI for CBF images.
 */
public class CbfImageWriterSpi extends ImageWriterSpi {
  private static final String VENDOR_NAME = "IMCA-CAT";
  private static final String VERSION = Version.ID;
  private static final String[] FORMAT_NAMES = { "cbf", "CBF" };
  private static final String[] FORMAT_SUFFIXES = { "cbf" };
  private static final String[] MIME_TYPES = { "image/x-cbf" };
  private static final String WRITER_CLASS_NAME = "imcacat.jcbf.CbfImageWriter";
  private static final String[] READER_SPI_CLASS_NAMES = { "imcacat.jcbf.CbfImageReaderSpi" };
  private static final String METADATA_FORMAT_NAME = "imcacat.jcbf.CbfMetadata_1.0";
  private static final String METADATA_FORMAT_CLASS_NAME = "imcacat.jcbf.CbfMetadataFormat";

  @SuppressWarnings("deprecation")
public CbfImageWriterSpi() {
    super(VENDOR_NAME, VERSION, FORMAT_NAMES, FORMAT_SUFFIXES, MIME_TYPES, WRITER_CLASS_NAME,
      STANDARD_OUTPUT_TYPE, READER_SPI_CLASS_NAMES, false, null, null, null, null, false,
      METADATA_FORMAT_NAME, METADATA_FORMAT_CLASS_NAME, null, null);
  }

  @Override
  public boolean canEncodeImage(ImageTypeSpecifier type) {
    return type.getBufferedImageType() == BufferedImage.TYPE_BYTE_BINARY
      || (type.getNumBands() == 1 && type.getNumComponents() == 1);
  }

  @Override
  public ImageWriter createWriterInstance(Object extension) throws IOException {
    return new CbfImageWriter(this);
  }

  @Override
  public String getDescription(Locale locale) {
    return "CBF image writer";
  }

}
