/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertEquals;

import org.junit.Test;

import ch.psi.imagej.cbf.Base64;

/**
 * I test <code>Base64</code>.
 */
public class Base64Test extends TestUtils {
  @Test
  public void testEncode01() {
    assertEquals("YWRtaW46YWRtaW4=", Base64.encode(asciiBytes("admin:admin")));
    assertEquals("YWRtaW46YWRtaQ==", Base64.encode(asciiBytes("admin:admi")));
    assertEquals("YWRtaW46YWRt", Base64.encode(asciiBytes("admin:adm")));
    assertEquals("", Base64.encode(asciiBytes("")));
    assertEquals("YQ==", Base64.encode(asciiBytes("a")));
    assertEquals("YWI=", Base64.encode(asciiBytes("ab")));
    assertEquals("YWJj", Base64.encode(asciiBytes("abc")));
    assertEquals("QWxhZGRpbjpvcGVuIHNlc2FtZQ==", Base64.encode(asciiBytes("Aladdin:open sesame")));
  }

  /* Source data outside of US-ASCII range. */
  @Test
  public void testEncode02() {
    byte[] source = new byte[] { 0 };
    assertEquals("AA==", Base64.encode(source));
    source = new byte[] { -1 };
    assertEquals("/w==", Base64.encode(source));
    source = new byte[] { 1 };
    assertEquals("AQ==", Base64.encode(source));
    source = new byte[] { (byte)200, (byte)202, (byte)204, (byte)205, (byte)207 };
    assertArrayEquals(source, Base64.decode(Base64.encode(source)));
    source = new byte[] { 0, -2, -4, -5, -7 };
    assertArrayEquals(source, Base64.decode(Base64.encode(source)));
    source = new byte[] { Byte.MIN_VALUE, Byte.MAX_VALUE, -1 };
    assertArrayEquals(source, Base64.decode(Base64.encode(source)));
  }

  @Test
  public void testDecode01() {
    assertArrayEquals(asciiBytes("admin:admin"), Base64.decode("YWRtaW46YWRtaW4="));
    assertArrayEquals(asciiBytes("admin:admi"), Base64.decode("YWRtaW46YWRtaQ=="));
    assertArrayEquals(asciiBytes("admin:adm"), Base64.decode("YWRtaW46YWRt"));
    assertArrayEquals(asciiBytes(""), Base64.decode(""));
    assertArrayEquals(asciiBytes("a"), Base64.decode("YQ=="));
    assertArrayEquals(asciiBytes("ab"), Base64.decode("YWI="));
    assertArrayEquals(asciiBytes("abc"), Base64.decode("YWJj"));
    assertArrayEquals(asciiBytes("Aladdin:open sesame"),
      Base64.decode("QWxhZGRpbjpvcGVuIHNlc2FtZQ=="));
  }

  /* Invalid character. */
  @Test(expected = IllegalArgumentException.class)
  public void testDecode02() {
    Base64.decode("Y;RtaW46YWRtaW4=");
  }

  /* Padding character is invalid when not at end. */
  @Test(expected = IllegalArgumentException.class)
  public void testDecode03() {
    Base64.decode("YW=taW46YWRtaW4=");
  }

  /* Invalid length. */
  @Test(expected = IllegalArgumentException.class)
  public void testDecode04() {
    Base64.decode("YRtaW46YWRtaW4=");
  }
}
