/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertEquals;

import org.junit.Test;

import ch.psi.imagej.cbf.CbfMetadata;

/**
 * I test <code>CbfMetadata</code>.
 */
public class CbfMetadataTest extends TestUtils {
  @Test(expected = IllegalArgumentException.class)
  public void testSetHeaderDetector01() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector("PILATUS 6M\r\nHosed");
  }

  @Test
  public void testSetHeaderDetector02() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector(null);
    assertNull(mdata.getHeaderDetectorName());
    assertNull(mdata.getHeaderDetectorSerialNumber());
    assertNull(mdata.getHeaderDetectorDescription());
  }

  @Test
  public void testSetHeaderDetector03() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector("PILATUS 6M, 60-0002, IMCA-CAT");
    assertEquals("PILATUS 6M", mdata.getHeaderDetectorName());
    assertEquals("60-0002", mdata.getHeaderDetectorSerialNumber());
    assertEquals("IMCA-CAT", mdata.getHeaderDetectorDescription());
  }

  @Test
  public void testSetHeaderDetector04() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector("PILATUS 6M, 60-0001, X06SA@SLS");
    assertEquals("PILATUS 6M", mdata.getHeaderDetectorName());
    assertEquals("60-0001", mdata.getHeaderDetectorSerialNumber());
    assertEquals("X06SA@SLS", mdata.getHeaderDetectorDescription());
  }

  @Test
  public void testSetHeaderDetector05() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector("PILATUS 6M SN: 60-0003");
    assertEquals("PILATUS 6M", mdata.getHeaderDetectorName());
    assertEquals("60-0003", mdata.getHeaderDetectorSerialNumber());
    assertNull(mdata.getHeaderDetectorDescription());
  }

  @Test
  public void testSetHeaderDetector06() {
    CbfMetadata mdata = new CbfMetadata();
    mdata.setHeaderDetector("PILATUS 6M IMCA-CAT");
    assertNull(mdata.getHeaderDetectorName());
    assertNull(mdata.getHeaderDetectorSerialNumber());
    assertNull(mdata.getHeaderDetectorDescription());
  }

  @Test
  public void testGetAsTree01() {
    (new CbfMetadata()).getAsTree(CbfMetadata.NATIVE_FORMAT_NAME);
  }
}
